@@ -45,7 +45,7 @@ use PPIx::Regexp::Constant qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.064';
+our $VERSION = '0.066';
 
 sub __new {
     my ( $class, $content, %arg ) = @_;
@@ -70,7 +70,13 @@ sub perl_version_introduced {
     my ( $self ) = @_;
     exists $self->{perl_version_introduced}
 	and return $self->{perl_version_introduced};
-    ( my $content = $self->content() ) =~ m/ \A \\ o /smx
+    my $content = $self->content();
+    my $main = $self->main_structure();
+    $main
+	and $content =~ m/ \A \\ N \{ /smx
+	and not $main->interpolates()
+	and return ( $self->{perl_version_introduced} = '5.029010' );
+    $content =~ m/ \A \\ o /smx
 	and return ( $self->{perl_version_introduced} = '5.013003' );
     $content =~ m/ \A \\ N [{] U [+] /smx
 	and return ( $self->{perl_version_introduced} = '5.008' );
@@ -431,8 +437,9 @@ It is analogous to the C<ord> built-in.
 
 It will not attempt to determine the ordinal of a unicode name
 (C<\N{...}>) unless L<charnames|charnames> has been loaded, and supports
-the L<vianame()|charnames/vianame> function. Instead, it will return
-C<undef>. Users of Perl 5.6.2 and older may be out of luck here.
+the L<vianame()|charnames/charnames::vianame(I<name>)> function.
+Instead, it will return C<undef>. Users of Perl 5.6.2 and older may be
+out of luck here.
 
 Unicode code points (e.g. C<\N{U+abcd}>) should work independently of
 L<charnames|charnames>, and just return the value of C<abcd>.
