@@ -17,12 +17,12 @@ our @EXPORT_OK = qw{
     __ns_can __to_ordinal_en
 };
 
-our $VERSION = '0.064';
+our $VERSION = '0.066';
 
 {
 
     my @ppi_zoo = (
-	[ 'PPI::Token::Regexp::Transliterate' ],
+	[ 'PPI::Token::Regexp::Transliterate', '' ],
 
 	[ 'PPI::Token::Regexp', 'PPIx::Regexp::Tokenizer' ],
 	[ 'PPI::Token::QuoteLike::Regexp', 'PPIx::Regexp::Tokenizer' ],
